[16/17] staging: vt6655: changed variable name: s_cbFillTxBufHead

Message ID f1e8c3693937ab4d2d7c9765cea1432fa6000df1.1666740522.git.tanjubrunostar0@gmail.com
State New
Headers
Series staging: vt6655: a series of checkpatch fixes on the file: rxtx.c |

Commit Message

Tanjuate Brunostar Oct. 25, 2022, 11:37 p.m. UTC
  change variable names s_cbFillTxBufHead to meet the
linux coding standard, as it says to avoid using camelCase naming
style. Cought by checkpatch

Signed-off-by: Tanjuate Brunostar <tanjubrunostar0@gmail.com>
---
 drivers/staging/vt6655/rxtx.c | 30 +++++++++++++++---------------
 1 file changed, 15 insertions(+), 15 deletions(-)
  

Patch

diff --git a/drivers/staging/vt6655/rxtx.c b/drivers/staging/vt6655/rxtx.c
index 6a54f234261a..90e7330680d9 100644
--- a/drivers/staging/vt6655/rxtx.c
+++ b/drivers/staging/vt6655/rxtx.c
@@ -15,7 +15,7 @@ 
  *      cbGetFragCount - Calculate fragment number count
  *      csBeacon_xmit - beacon tx function
  *      csMgmt_xmit - management tx function
  *      s_cbFillTxBufHead - fulfill tx dma buffer header
  *      s_uGetDataDuration - get tx data required duration
  *      s_uFillDataHead- fulfill tx data duration header
  *      s_uGetRTSCTSDuration- get rtx/cts required duration
@@ -107,12 +107,12 @@  static void s_vgenerate_tx_parameter(struct vnt_private *p_device,
 				     void *ps_eth_header,
 				     unsigned short wCurrentRate);
 
-static unsigned int s_cbFillTxBufHead(struct vnt_private *p_device,
-				      unsigned char by_pkt_type,
-				      unsigned char *pbyTxBufferAddr,
-				      unsigned int u_dma_idx,
-				      struct vnt_tx_desc *pHeadTD,
-				      unsigned int uNodeIndex);
+static unsigned int s_cb_fill_tx_buf_head(struct vnt_private *p_device,
+					  unsigned char by_pkt_type,
+					  unsigned char *pbyTxBufferAddr,
+					  unsigned int u_dma_idx,
+					  struct vnt_tx_desc *pHeadTD,
+					  unsigned int uNodeIndex);
 
 static __le16 s_uFillDataHead(struct vnt_private *p_device,
 			      unsigned char by_pkt_type,
@@ -1043,12 +1043,12 @@  static void s_vgenerate_tx_parameter(struct vnt_private *p_device,
 	}
 }
 
-static unsigned int s_cbFillTxBufHead(struct vnt_private *p_device,
-				      unsigned char by_pkt_type,
-				      unsigned char *pbyTxBufferAddr,
-				      unsigned int u_dma_idx,
-				      struct vnt_tx_desc *pHeadTD,
-				      unsigned int is_pspoll)
+static unsigned int s_cb_fill_tx_buf_head(struct vnt_private *p_device,
+					  unsigned char by_pkt_type,
+					  unsigned char *pbyTxBufferAddr,
+					  unsigned int u_dma_idx,
+					  struct vnt_tx_desc *pHeadTD,
+					  unsigned int is_pspoll)
 {
 	struct vnt_td_info *td_info = pHeadTD->td_info;
 	struct sk_buff *skb = td_info->skb;
@@ -1442,8 +1442,8 @@  int vnt_generate_fifo_header(struct vnt_private *priv, u32 dma_idx,
 
 	tx_buffer_head->frag_ctl |= cpu_to_le16(FRAGCTL_NONFRAG);
 
-	s_cbFillTxBufHead(priv, pkt_type, (u8 *)tx_buffer_head,
-			  dma_idx, head_td, is_pspoll);
+	s_cb_fill_tx_buf_head(priv, pkt_type, (u8 *)tx_buffer_head,
+			      dma_idx, head_td, is_pspoll);
 
 	if (info->control.hw_key) {
 		tx_key = info->control.hw_key;
@@ -15,7 +15,7 @@ 
  *      csBeacon_xmit - beacon tx function
  *      csMgmt_xmit - management tx function
- *      s_cbFillTxBufHead - fulfill tx dma buffer header
+ *      s_cb_fill_tx_buf_head - fulfill tx dma buffer header
  *      s_uGetDataDuration - get tx data required duration
  *      s_uFillDataHead- fulfill tx data duration header